package com.example.zijincao.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.zijincao.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.zijincao.entity.TaCountry;
import com.example.zijincao.service.TaCountryService;

 /**
 * 国家种植表;(ta_country)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-9
 */
@Api(tags = "国家种植表对象功能接口")
@RestController
@RequestMapping("/wx")
public class TaCountryController {
    
    @Autowired
    private TaCountryService taCountryService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taCountry/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(taCountryService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taCountry")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaCountry> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaCountry> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaCountry> result = taCountryService.page(pg);
        
        return ResponseBean.success(result);
    }
    
//    /**
//     * 新增数据
//     *
//     * @param taCountry 实例对象
//     * @return 实例对象
//     */
//    @ApiOperation("新增数据")
//    @PostMapping("/taCountry")
//    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaCountry taCountry) throws Exception {
//        taCountryService.save(taCountry);
//        return ResponseBean.success(taCountry);
//    }
    
    /** 
     * 更新数据
     *
     * @param taCountry 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taCountry")
    public ResponseBean edit(@ApiParam("国家名称") @RequestBody TaCountry taCountry) throws Exception {
        String name = taCountry.getName();
        if (null == name || "".equals(name)) {
            return ResponseBean.error("国家名称不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaCountry origin = taCountryService.getExistBy("name", name, false, false);
        if (null == origin) {
            origin = new TaCountry();
            origin.setName(name);
            origin.setNum(0);
            taCountryService.save(origin);
        } else {
            taCountryService.updateByName(name, 1);
            origin.setNum(origin.getNum() + 1);
        }

        return ResponseBean.success(origin);
    }
    
//    /**
//     * 通过主键删除数据
//     *
//     * @param id 主键
//     * @return 是否成功
//     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/taCountry/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
//        taCountryService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }
}