package com.example.zijincao.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.zijincao.common.IpUtil;
import com.example.zijincao.common.ResponseBean;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import me.chanjar.weixin.common.bean.WxOAuth2UserInfo;
import me.chanjar.weixin.common.bean.oauth2.WxOAuth2AccessToken;
import me.chanjar.weixin.mp.api.WxMpService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.example.zijincao.entity.TaTrack;
import com.example.zijincao.service.TaTrackService;

import javax.servlet.http.HttpServletRequest;

/**
 * 埋点表;(ta_track)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-7
 */
@Api(tags = "埋点表对象功能接口")
@RequiredArgsConstructor
@RestController
@RequestMapping("/")
public class TaTrackController {
    
    @Autowired
    private TaTrackService taTrackService;

     private final WxMpService wxService;

     @Value("${yz.initNum}")
     private Integer initNum;

    /** 
     * 通过ID查询单条数据 
     *
     * @param serialNo 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taTrack/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(taTrackService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taTrack")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaTrack> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaTrack> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaTrack> result = taTrackService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taTrack 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/wx/taTrack")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaTrack taTrack,
                            HttpServletRequest request) throws Exception {

        if (null == taTrack.getIp() || "".equals(taTrack.getIp())) {
            String ipAddr = IpUtil.getIpAddr(request);
            taTrack.setIp(ipAddr);
        }

        String testCode = "123";
        WxOAuth2UserInfo user = null;
        if (null != taTrack.getCode() && !"".equals(taTrack.getCode()) && !testCode.equals(taTrack.getCode())) {
            WxOAuth2AccessToken accessToken = wxService.getOAuth2Service().getAccessToken(taTrack.getCode());
            user = wxService.getOAuth2Service().getUserInfo(accessToken, null);

            taTrack.setOpenid(user.getOpenid());
            taTrack.setAvatar(user.getHeadImgUrl());
            taTrack.setNickname(user.getNickname());
        }

        taTrackService.save(taTrack);

        long count = taTrackService.count();

        Map<String, Object> resp = new HashMap<>();
        resp.put("user", user);
        resp.put("num", count + initNum);

        return ResponseBean.success(resp);
    }
    
//    /**
//     * 更新数据
//     *
//     * @param taTrack 实例对象
//     * @return 实例对象
//     */
//    @ApiOperation("更新数据")
//    @PutMapping("/taTrack/{id}")
//    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaTrack taTrack,
//                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
//        taTrackService.updateById(taTrack);
//        return ResponseBean.success(taTrack);
//    }
//
//    /**
//     * 通过主键删除数据
//     *
//     * @param serialNo 主键
//     * @return 是否成功
//     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/taTrack/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
//        taTrackService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }
}